==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/DAL/Interfaces/DbInterface.php <==
<?php
namespace Claromentis\Core\DAL\Interfaces;

$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] ?: array()) + array();
use Claromentis\Core\DAL\Query;
use Claromentis\Core\DAL\Query2;
use Claromentis\Core\DAL\QueryBuilder;
use Claromentis\Core\DAL\ResultInterface;




interface DbInterface extends TransactionInterface, QueryLogInterface
{
    
    
    
    
    
    
    public function type() : string;
    
    
    
    
    
    
    
    
    public function query($q, ...$params) : ResultInterface;
    
    
    
    
    
    
    
    
    
    public function query_row($q, ...$params);
    
    
    
    
    
    
    
    
    
    
    
    
    public function query2($q, ...$params) : ResultInterface;
    
    
    
    
    
    
    public function query2_row($q, ...$params);
    
    
    
    
    
    
    public function insertId();
    
    
    
    
    
    
    public function affected();
    
    
    
    
    
    
    public function DisableTokenCheck();
    
    
    
    
    
    
    public function EnableTokenCheck();
    
    
    
    
    
    
    
    
    
    
    
    
    public function concat_ws(string $separator, ...$fields) : string;
    
    
    
    
    
    
    
    
    
    
    public function cond_if(string $condition, string $value_if_true, string $value_if_false) : string;
    
    
    
    
    
    
    
    
    public function bitwiseand(string $value1, string $value2) : string;
    
    
    
    
    
    
    
    
    public function Date14ToUnix(string $date) : string;
    
    
    
    
    
    
    
    
    public function UnixToDate14(string $date) : string;
    
    
    
    
    
    
    
    
    
    public function substring(string $string, int $position, $length = false) : string;
    
    
    
    
    
    
    public function GetTmpPrefix() : string;
    
    
    
    
    
    
    
    public function IsReservedWord(string $word) : bool;
    
    
    
    
    
    
    
    public function GetQueryBuilder(string $str) : QueryBuilder;
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/DAL/Interfaces/DbInterface.php <==
<?php
namespace Claromentis\Core\DAL\Interfaces;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] ?: array()) + array();
use Claromentis\Core\DAL\Query;
use Claromentis\Core\DAL\Query2;
use Claromentis\Core\DAL\QueryBuilder;
use Claromentis\Core\DAL\ResultInterface;




interface DbInterface extends TransactionInterface, QueryLogInterface
{
    
    
    
    
    
    
    public function type() : string;
    
    
    
    
    
    
    
    
    public function query($q, ...$params) : ResultInterface;
    
    
    
    
    
    
    
    
    
    public function query_row($q, ...$params);
    
    
    
    
    
    
    
    
    
    
    
    
    public function query2($q, ...$params) : ResultInterface;
    
    
    
    
    
    
    public function query2_row($q, ...$params);
    
    
    
    
    
    
    public function insertId();
    
    
    
    
    
    
    public function affected();
    
    
    
    
    
    
    public function DisableTokenCheck();
    
    
    
    
    
    
    public function EnableTokenCheck();
    
    
    
    
    
    
    
    
    
    
    
    
    public function concat_ws(string $separator, ...$fields) : string;
    
    
    
    
    
    
    
    
    
    
    public function cond_if(string $condition, string $value_if_true, string $value_if_false) : string;
    
    
    
    
    
    
    
    
    public function bitwiseand(string $value1, string $value2) : string;
    
    
    
    
    
    
    
    
    public function Date14ToUnix(string $date) : string;
    
    
    
    
    
    
    
    
    public function UnixToDate14(string $date) : string;
    
    
    
    
    
    
    
    
    
    public function substring(string $string, int $position, $length = false) : string;
    
    
    
    
    
    
    public function GetTmpPrefix() : string;
    
    
    
    
    
    
    
    public function IsReservedWord(string $word) : bool;
    
    
    
    
    
    
    
    public function GetQueryBuilder(string $str) : QueryBuilder;
}
